# Text2SQL-LTM - Commercial License & Advanced Protection
# Copyright (c) 2024 Dr. Alban Maxhuni. All rights reserved.
# Contact: info@albanmaxhuni.com
# 
# LEGAL NOTICE:
# This software is protected by commercial license and obfuscation.
# Unauthorized reverse engineering, decompilation, or redistribution is prohibited.
# Commercial license required for production use.
# For licensing inquiries: info@albanmaxhuni.com
#
# TECHNICAL PROTECTION: String obfuscation, license enforcement

"""
Memory management system for TEXT2SQL-LTM using mem0.ai.

This module provides comprehensive memory management capabilities including:
- User memory isolation and management
- Long-term memory storage and retrieval
- Memory lifecycle management
- Context-aware memory operations
- Performance optimization and caching
"""

from .manager import MemoryManager
from .config import MemoryConfig
from .storage import MemoryStorage, RedisStorage, PostgreSQLStorage, MongoDBStorage
from .lifecycle import MemoryLifecycleManager
from .isolation import UserMemoryIsolation
from .context import MemoryContext, ContextualMemory
from .optimization import MemoryOptimizer
from .analytics import MemoryAnalytics

__all__ = [
    # Core classes
    "MemoryManager",
    "MemoryConfig",
    
    # Storage backends
    "MemoryStorage",
    "RedisStorage", 
    "PostgreSQLStorage",
    "MongoDBStorage",
    
    # Memory management
    "MemoryLifecycleManager",
    "UserMemoryIsolation",
    
    # Context and retrieval
    "MemoryContext",
    "ContextualMemory",
    
    # Optimization and analytics
    "MemoryOptimizer",
    "MemoryAnalytics",
]
